name = "software"
hwid = ["software"]
class instrument:
    def __init__(self,port):
        pass
    def gather_data(self):
        return 1, 2
